@@ -18,7 +18,7 @@ perAnnoSchedule schedule date = (yearEnd date, effectiveRate)
   where
     (_, effectiveRate) = last $ takeWhile (\(fromDate, _) -> fromDate<date) sortedSchedule
     sortedSchedule = sortOn fst schedule
-        
+
 day :: Integer -> Int -> Int -> Day
 day = fromGregorian
 
@@ -59,17 +59,29 @@ basiszinsTable =
   , (day 2011 07 01, day 2011 12 31,  37 / 10000)
   , (day 2012 01 01, day 2012 06 30,  12 / 10000)
   , (day 2012 07 01, day 2012 12 31,  12 / 10000)
-  , (day 2013 01 01, day 2013 06 30, -13 / 10000)
-  , (day 2013 07 01, day 2013 12 31, -38 / 10000)
-  , (day 2014 01 01, day 2014 06 30, -63 / 10000)
-  , (day 2014 07 01, day 2014 12 31, -73 / 10000)
-  , (day 2015 01 01, day 2015 06 30, -83 / 10000)
-  , (day 2015 07 01, day 2015 12 31, -83 / 10000)
-  , (day 2016 01 01, day 2016 06 30, -83 / 10000)
-  , (day 2016 07 01, day 2016 12 31, -88 / 10000)
-  , (day 2017 01 01, day 2017 06 30, -88 / 10000)
-  , (day 2017 07 01, day 2017 12 31, -88 / 10000)
-  , (day 2018 01 01, day 2018 06 30, -88 / 10000)
+  , (day 2013 01 01, day 2013 06 30, (-13) / 10000)
+  , (day 2013 07 01, day 2013 12 31, (-38) / 10000)
+  , (day 2014 01 01, day 2014 06 30, (-63) / 10000)
+  , (day 2014 07 01, day 2014 12 31, (-73) / 10000)
+  , (day 2015 01 01, day 2015 06 30, (-83) / 10000)
+  , (day 2015 07 01, day 2015 12 31, (-83) / 10000)
+  , (day 2016 01 01, day 2016 06 30, (-83) / 10000)
+  , (day 2016 07 01, day 2016 12 31, (-88) / 10000)
+  , (day 2017 01 01, day 2017 06 30, (-88) / 10000)
+  , (day 2017 07 01, day 2017 12 31, (-88) / 10000)
+  , (day 2018 01 01, day 2018 06 30, (-88) / 10000)
+  , (day 2019 01 01, day 2019 06 30, (-88) / 10000)
+  , (day 2019 07 01, day 2019 12 31, (-88) / 10000)
+  , (day 2020 01 01, day 2020 06 30, (-88) / 10000)
+  , (day 2020 07 01, day 2020 12 31, (-88) / 10000)
+  , (day 2021 01 01, day 2021 06 30, (-88) / 10000)
+  , (day 2021 07 01, day 2021 12 31, (-88) / 10000)
+  , (day 2022 01 01, day 2022 06 30, (-88) / 10000)
+  , (day 2022 07 01, day 2022 12 31, (-88) / 10000)
+  , (day 2023 01 01, day 2023 06 30, 162 / 10000)
+  , (day 2023 07 01, day 2023 12 31, 312 / 10000)
+  , (day 2024 01 01, day 2024 06 30, 362 / 10000)
+  , (day 2024 07 01, day 2024 12 31, 337 / 10000)
   ]
 
 ingDiba :: Rate
